Crate rgpui_component

Crate rgpui_component 

Re-exports

pub use crate::Disableable;
pub use global_state::GlobalState;
pub use input::RopeExt;
pub use input::RopeLines;
pub use theme::*;

Modules

accordion
actions
alert
animation
avatar
badge
breadcrumb
button
calendar
chart
checkbox
clipboard
collapsible
color_picker
combobox
date_picker
description_list
dialog
对话框模块
dock
form
global_state
group_box
highlighter
history
hover_card
input
kbd
label
link
list
menu
native_menu
A menu rendered natively by the operating system.
notification
pagination
plot
popover
progress
radio
rating
resizable
scroll
searchable_list
select
separator
setting
sheet
sidebar
skeleton
slider
spinner
status_bar
stepper
styled_ext_reflection
实现函数反射
switch
tab
table
tag
text
theme
tooltip
tree

Macros

icon_named
通过扫描 SVG 文件目录生成自定义图标枚举及其 IconNamed 实现。

Structs

AnyChildElement
A type-erased element that can accept a [AnyChildElementOptions] before being rendered.
DivInspector
Edges
A struct for defining the edges of an element.
Icon
IndexPath
Represents an index path in a list, which consists of a section index,
Measure
Root
Root is a view for the App window for as the top level view (Must be the first view in the window).
Rope
A utf8 text rope.
TitleBar
TitleBar used to customize the appearance of the title bar.
ToggleInspector
VirtualList
虚拟列表组件,用于渲染大量不同尺寸的项
VirtualListScrollHandle
VirtualList 的滚动句柄
WindowBorder
Window border use to render a custom window border and shadow for Linux.

Enums

IconName
Placement
A enum for defining the placement of the element.
Side
A enum for defining the side of the element.
Size
A size for elements.

Constants

TITLE_BAR_HEIGHT

Traits

AxisExt
A trait to extend the Axis enum with utility methods.
ChildElement
Collapsible
A trait for defining element that can be collapsed.
Disableable
A trait for defining element that can be disabled.
ElementExt
A trait to extend [gpui::Element] with additional functionality.
FocusTrapElement
An extension trait to add focus_trap functionality to interactive elements.
IconNamed
Types implementing this trait can automatically be converted to Icon.
InteractiveElementExt
LengthExt
A trait to extend the Length enum with utility methods.
Selectable
A trait for defining element that can be selected.
Sizable
A trait for setting the size of an element. Size::Medium is use by default.
StyleSized
StyledExt
Extends rgpui::Styled with specific styling methods.
WindowExt
Extension trait for Window to add dialog, sheet .. functionality.

Functions

box_shadow
Create a BoxShadow like CSS.
h_flex
Returns a Div as horizontal flex layout.
h_virtual_list
创建水平方向的 VirtualList
init
Initialize the components.
locale
measure
Measures the execution time.
measure_if
Measures the execution time of a function and logs it if if_ is true.
set_locale
v_flex
Returns a Div as vertical flex layout.
v_virtual_list
创建垂直方向的 VirtualList
window_border
Create a new window border.
window_paddings
Get the window paddings.