Alert

Struct Alert 

pub struct Alert { /* private fields */ }
Alert used to display a message to the user.

Implementations

Source

impl Alert

pub fn new(id: impl Into<ElementId>, message: impl Into<Text>) -> Self

Create a new alert with the given message.

pub fn info(id: impl Into<ElementId>, message: impl Into<Text>) -> Self

Create a new info AlertVariant::Info with the given message.

pub fn success(id: impl Into<ElementId>, message: impl Into<Text>) -> Self

Create a new AlertVariant::Success alert with the given message.

pub fn warning(id: impl Into<ElementId>, message: impl Into<Text>) -> Self

Create a new AlertVariant::Warning alert with the given message.

pub fn error(id: impl Into<ElementId>, message: impl Into<Text>) -> Self

Create a new AlertVariant::Error alert with the given message.

pub fn with_variant(self, variant: AlertVariant) -> Self

Sets the AlertVariant of the alert.

pub fn icon(self, icon: impl Into<Icon>) -> Self

Set the icon for the alert.

pub fn title(self, title: impl Into<SharedString>) -> Self

Set the title for the alert.

pub fn banner(self) -> Self

Set alert as banner style.

The banner style will make the alert take the full width of the container and not border and radius. This mode will not display title.

pub fn visible(self, visible: bool) -> Self

Set the visibility of the alert.

pub fn on_close( self, on_close: impl Fn(&ClickEvent, &mut Window, &mut App) + 'static, ) -> Self

Set alert as closable, true will show Close icon.