pub enum Matcher {
DayOfWeek(Vec<u32>),
Interval(IntervalMatcher),
Range(RangeMatcher),
Custom(Box<dyn Fn(&NaiveDate) -> bool + Send + Sync>),
}Expand description
Matcher to match dates.
Variants
DayOfWeek(Vec<u32>)
Match declare days of the week.
Matcher::DayOfWeek(vec![0, 6]) Will match the days of the week that are Sunday and Saturday.
Interval(IntervalMatcher)
Match the included days, except for those before and after the interval.
Matcher::Interval(IntervalMatcher { before: Some(NaiveDate::from_ymd(2020, 1, 2)), after: Some(NaiveDate::from_ymd(2020, 1, 3)), }) Will match the days that are not between 2020-01-02 and 2020-01-03.
Range(RangeMatcher)
Match the days within the range.
Matcher::Range(RangeMatcher { from: Some(NaiveDate::from_ymd(2020, 1, 1)), to: Some(NaiveDate::from_ymd(2020, 1, 3)), }) Will match the days that are between 2020-01-01 and 2020-01-03.
Custom(Box<dyn Fn(&NaiveDate) -> bool + Send + Sync>)
Match dates using a custom function.
let matcher = Matcher::Custom(Box::new(|date: &NaiveDate| { date.day0() < 5 })); Will match first 5 days of each month
Implementations