pub struct PieChart<T: 'static> { /* private fields */ }Implementations
Sourceimpl<T> PieChart<T>
impl<T> PieChart<T>
pub fn new<I>(data: I) -> Selfwhere
I: IntoIterator<Item = T>,
Sourcepub fn inner_radius(self, inner_radius: f32) -> Self
pub fn inner_radius(self, inner_radius: f32) -> Self
Set the inner radius of the pie chart.
Sourcepub fn inner_radius_fn(
self,
inner_radius_fn: impl Fn(&ArcData<'_, T>) -> f32 + 'static,
) -> Self
pub fn inner_radius_fn( self, inner_radius_fn: impl Fn(&ArcData<'_, T>) -> f32 + 'static, ) -> Self
Set the inner radius of the pie chart based on the arc data.
Sourcepub fn outer_radius(self, outer_radius: f32) -> Self
pub fn outer_radius(self, outer_radius: f32) -> Self
Set the outer radius of the pie chart.
Sourcepub fn outer_radius_fn(
self,
outer_radius_fn: impl Fn(&ArcData<'_, T>) -> f32 + 'static,
) -> Self
pub fn outer_radius_fn( self, outer_radius_fn: impl Fn(&ArcData<'_, T>) -> f32 + 'static, ) -> Self
Set the outer radius of the pie chart based on the arc data.
pub fn value(self, value: impl Fn(&T) -> f32 + 'static) -> Self