pub struct DatePickerState { /* private fields */ }Expand description
Use to store the state of the date picker.
Implementations
Sourceimpl DatePickerState
impl DatePickerState
Sourcepub fn range(window: &mut Window, cx: &mut Context<'_, Self>) -> Self
pub fn range(window: &mut Window, cx: &mut Context<'_, Self>) -> Self
Create a date state with range mode.
Sourcepub fn date_format(self, format: impl Into<SharedString>) -> Self
pub fn date_format(self, format: impl Into<SharedString>) -> Self
Set the date format of the date picker to display in Input, default: “%Y/%m/%d”.
Sourcepub fn number_of_months(self, number_of_months: usize) -> Self
pub fn number_of_months(self, number_of_months: usize) -> Self
Set the number of months calendar view to display, default is 1.
Sourcepub fn set_date(
&mut self,
date: impl Into<Date>,
window: &mut Window,
cx: &mut Context<'_, Self>,
)
pub fn set_date( &mut self, date: impl Into<Date>, window: &mut Window, cx: &mut Context<'_, Self>, )
Set the date of the date picker.
Sourcepub fn disabled_matcher(self, disabled: impl Into<Matcher>) -> Self
pub fn disabled_matcher(self, disabled: impl Into<Matcher>) -> Self
Set the disabled match for the calendar.
Sourcepub fn set_year_range(&mut self, range: (i32, i32), cx: &mut Context<'_, Self>)
pub fn set_year_range(&mut self, range: (i32, i32), cx: &mut Context<'_, Self>)
Set the year range for the internal calendar.
Default is 50 years before and after the current year.
range uses a half-open interval (start, end) where end is exclusive.