GlobalState

Struct GlobalState 

pub struct GlobalState { /* private fields */ }

Implementations

Source

impl GlobalState

pub fn suppress_text_selection(cx: &mut App)

Suppress the window-level text selection for the current mouse down.

Call this from a mouse-down handler (bubble phase) of a component that owns its own press/drag interaction, so that pressing it does not start a window text selection. The flag is reset on the next mouse down.

pub fn global(cx: &App) -> &Self

pub fn global_mut(cx: &mut App) -> &mut Self

pub fn is_in_deferred_context(&self) -> bool

Check if we are currently inside a deferred context (e.g., inside an open Popover).

pub fn app_menus(&self) -> &[OwnedMenu]

Get the application menus

pub fn set_app_menus(&mut self, menus: Vec<OwnedMenu>)

Set the application menus