pub enum PopupMenuItem {
Separator,
Label(SharedString),
Item {
icon: Option<Icon>,
label: SharedString,
disabled: bool,
checked: bool,
is_link: bool,
action: Option<Box<dyn Action>>,
handler: Option<Rc<dyn Fn(&ClickEvent, &mut Window, &mut App)>>,
},
ElementItem {
icon: Option<Icon>,
disabled: bool,
checked: bool,
action: Option<Box<dyn Action>>,
render: Box<dyn Fn(&mut Window, &mut App) -> AnyElement + 'static>,
handler: Option<Rc<dyn Fn(&ClickEvent, &mut Window, &mut App)>>,
},
Submenu {
icon: Option<Icon>,
label: SharedString,
disabled: bool,
menu: Entity<PopupMenu>,
},
}Expand description
An menu item in a popup menu.
Variants
Separator
A menu separator item.
Label(SharedString)
A non-interactive label item.
Item
A standard menu item.
Fields
label: SharedStringElementItem
A menu item with custom element render.
Fields
A submenu item that opens another popup menu.
NOTE: This is only supported when the parent menu is not scrollable.
Implementations
Sourceimpl PopupMenuItem
impl PopupMenuItem
Sourcepub fn new(label: impl Into<SharedString>) -> Self
pub fn new(label: impl Into<SharedString>) -> Self
Create a new menu item with the given label.
Create a new submenu item that opens another popup menu.
Sourcepub fn label(label: impl Into<SharedString>) -> Self
pub fn label(label: impl Into<SharedString>) -> Self
Creates a label menu item.
Sourcepub fn icon(self, icon: impl Into<Icon>) -> Self
pub fn icon(self, icon: impl Into<Icon>) -> Self
Set the icon for the menu item.
Only works for PopupMenuItem::Item, PopupMenuItem::ElementItem and PopupMenuItem::Submenu.
Sourcepub fn action(self, action: Box<dyn Action>) -> Self
pub fn action(self, action: Box<dyn Action>) -> Self
Set the action for the menu item.
Only works for PopupMenuItem::Item and PopupMenuItem::ElementItem.
Sourcepub fn disabled(self, disabled: bool) -> Self
pub fn disabled(self, disabled: bool) -> Self
Set the disabled state for the menu item.
Only works for PopupMenuItem::Item, PopupMenuItem::ElementItem and PopupMenuItem::Submenu.
Sourcepub fn checked(self, checked: bool) -> Self
pub fn checked(self, checked: bool) -> Self
Set checked state for the menu item.
NOTE: If check_side is Side::Left, the icon will replace with a check icon.
Sourcepub fn on_click<F>(self, handler: F) -> Self
pub fn on_click<F>(self, handler: F) -> Self
Add a click handler for the menu item.
Only works for PopupMenuItem::Item and PopupMenuItem::ElementItem.