pub trait DropdownMenu:
Styled
+ Selectable
+ InteractiveElement
+ IntoElement
+ 'static {
// Provided methods
fn dropdown_menu(
self,
f: impl Fn(PopupMenu, &mut Window, &mut Context<'_, PopupMenu>) -> PopupMenu + 'static,
) -> DropdownMenuPopover<Self> { ... }
fn dropdown_menu_with_anchor(
self,
anchor: impl Into<Anchor>,
f: impl Fn(PopupMenu, &mut Window, &mut Context<'_, PopupMenu>) -> PopupMenu + 'static,
) -> DropdownMenuPopover<Self> { ... }
}Expand description
A dropdown menu trait for buttons and other interactive elements
Provided Methods
Create a dropdown menu with the given items, anchored to the TopLeft corner
Create a dropdown menu with the given items, anchored to the given corner
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".