pub enum SearchableListChange {
Select {
index: IndexPath,
},
Deselect {
index: IndexPath,
},
}Expand description
A single, atomic selection change proposed by the mode-strategy for a user interaction.
Passed as a slice to [SearchableListDelegate::on_will_change], giving the delegate
a description of what the default strategy intends to do. The delegate may apply all,
some, or none of the changes by mutating the selection argument directly.
Variants