pub enum SidebarCollapsible {
Icon,
Offcanvas,
None,
}Expand description
The way a Sidebar behaves when it is collapsed.
This follows the shadcn/ui sidebar modes:
SidebarCollapsible::Iconcollapses the sidebar to icon width.SidebarCollapsible::Offcanvasslides the sidebar out and releases its layout width.SidebarCollapsible::Nonekeeps the sidebar expanded and ignores collapsed state.
Variants
Icon
Collapse the sidebar to icon width.
Offcanvas
Collapse the sidebar completely out of the layout.
None
Disable sidebar collapse.