pub struct Sidebar<E: SidebarItem + 'static> { /* private fields */ }Expand description
A Sidebar element that can contain collapsible child elements.
Implementations
Sourceimpl<E: SidebarItem> Sidebar<E>
impl<E: SidebarItem> Sidebar<E>
Sourcepub fn collapsible(self, collapsible: impl Into<SidebarCollapsible>) -> Self
pub fn collapsible(self, collapsible: impl Into<SidebarCollapsible>) -> Self
Set how the sidebar collapses.
Passing true keeps the previous behavior and maps to
SidebarCollapsible::Icon. Passing false maps to
SidebarCollapsible::None.
Sourcepub fn header(self, header: impl IntoElement) -> Self
pub fn header(self, header: impl IntoElement) -> Self
Set the header of the sidebar.
Set the footer of the sidebar.
Sourcepub fn child(self, child: E) -> Self
pub fn child(self, child: E) -> Self
Add a child element to the sidebar, the child must implement Collapsible
Sourcepub fn children(self, children: impl IntoIterator<Item = E>) -> Self
pub fn children(self, children: impl IntoIterator<Item = E>) -> Self
Add multiple children to the sidebar, the children must implement Collapsible