SidebarMenuItem

Struct SidebarMenuItem 

pub struct SidebarMenuItem { /* private fields */ }
Menu item for the SidebarMenu

Implementations

Source

impl SidebarMenuItem

pub fn new(label: impl Into<SharedString>) -> Self

Create a new SidebarMenuItem with a label.

pub fn icon(self, icon: impl Into<Icon>) -> Self

Set the icon for the menu item

pub fn active(self, active: bool) -> Self

Set the active state of the menu item

pub fn on_click( self, handler: impl Fn(&ClickEvent, &mut Window, &mut App) + 'static, ) -> Self

Add a click handler to the menu item

pub fn collapsed(self, collapsed: bool) -> Self

Set the collapsed state of the menu item

pub fn default_open(self, open: bool) -> Self

Set the default open state of the Submenu, default is false.

This only used on initial render, the internal state will be used afterwards.

pub fn click_to_open(self, click_to_open: bool) -> Self

Set whether clicking the menu item open the submenu.

Default is false.

If false we only handle open/close via the caret button.

pub fn click_to_toggle(self, click_to_toggle: bool) -> Self

Set whether clicking the menu item toggles the submenu.

If click_to_open is true, this has no effect.

Default is false.

pub fn children( self, children: impl IntoIterator<Item = impl Into<Self>>, ) -> Self

pub fn suffix<F, E>(self, builder: F) -> Self
where F: Fn(&mut Window, &mut App) -> E + 'static, E: IntoElement,

Set the suffix for the menu item.

pub fn disable(self, disable: bool) -> Self

Set disabled flat for menu item.

pub fn context_menu( self, f: impl Fn(PopupMenu, &mut Window, &mut App) -> PopupMenu + 'static, ) -> Self

Set the context menu for the menu item.