Switch

Struct Switch 

pub struct Switch { /* private fields */ }
A Switch element that can be toggled on or off.

Implementations

Source

impl Switch

pub fn new(id: impl Into<ElementId>) -> Self

Create a new Switch element.

pub fn checked(self, checked: bool) -> Self

Set the checked state of the switch.

pub fn label(self, label: impl Into<Text>) -> Self

Set the label of the switch.

pub fn on_click<F>(self, handler: F) -> Self
where F: Fn(&bool, &mut Window, &mut App) + 'static,

Add a click handler for the switch.

pub fn color(self, color: impl Into<Hsla>) -> Self

Set the background color of the switch when checked. Defaults to cx.theme().primary.

pub fn tooltip(self, tooltip: impl Into<SharedString>) -> Self

Set tooltip text for the switch.