Module text

Module text 

Structs

TextView
A text view that can render Markdown or HTML.
TextViewLayoutState
TextViewState
The state of a TextView.
TextViewStyle
TextViewStyle used to customize the style for [TextView].

Enums

Text

Functions

html
Create a new html text view with code location as id.
markdown
Create a new markdown text view with code location as id.
plain
创建一个新的纯文本文本视图,使用代码位置作为 id。