Module tree
rgpui_
component
0.3.0
Module tree
Module Items
Structs
Enums
Functions
In crate rgpui_
component
rgpui_component
Module
tree
Structs

Tree
A tree view element that displays hierarchical data.
Tree
Entry
A flat representation of a tree item with its depth.
Tree
Item
A tree item with a label, children, and an expanded state.
Tree
State
State for managing tree items.
Enums

Tree
Event
Event emitted by
TreeState
when user-visible state changes.
Functions

tree
Create a
Tree
.