TreeState

Struct TreeState 

pub struct TreeState { /* private fields */ }
State for managing tree items.

Implementations

Source

impl TreeState

pub fn new(cx: &mut App) -> Self

Create a new empty tree state.

pub fn items(self, items: impl Into<Vec<TreeItem>>) -> Self

Set the tree items.

pub fn set_items( &mut self, items: impl Into<Vec<TreeItem>>, cx: &mut Context<'_, Self>, )

Set the tree items.

pub fn selected_index(&self) -> Option<usize>

Get the currently selected index, if any.

pub fn set_selected_index( &mut self, ix: Option<usize>, cx: &mut Context<'_, Self>, )

Set the selected index, or None to clear selection.

pub fn set_selected_item( &mut self, item: Option<&TreeItem>, cx: &mut Context<'_, Self>, )

Set the selected index by tree item, or None to clear selection.

pub fn selected_item(&self) -> Option<&TreeItem>

Get the currently selected tree item, if any.

pub fn scroll_to_item(&mut self, ix: usize, strategy: ScrollStrategy)

pub fn selected_entry(&self) -> Option<&TreeEntry>

Get the currently selected entry, if any.

pub fn focus(&mut self, window: &mut Window, cx: &mut App)