pub struct GlobalState { /* private fields */ }Implementations
Sourceimpl GlobalState
impl GlobalState
Sourcepub fn suppress_text_selection(cx: &mut App)
pub fn suppress_text_selection(cx: &mut App)
Suppress the window-level text selection for the current mouse down.
Call this from a mouse-down handler (bubble phase) of a component that owns its own press/drag interaction, so that pressing it does not start a window text selection. The flag is reset on the next mouse down.
pub fn global(cx: &App) -> &Self
pub fn global_mut(cx: &mut App) -> &mut Self
Sourcepub fn is_in_deferred_context(&self) -> bool
pub fn is_in_deferred_context(&self) -> bool
Check if we are currently inside a deferred context (e.g., inside an open Popover).
Get the application menus
Set the application menus