pub struct SidebarMenuItem { /* private fields */ }Expand description
Menu item for the SidebarMenu
Implementations
Sourceimpl SidebarMenuItem
impl SidebarMenuItem
Sourcepub fn new(label: impl Into<SharedString>) -> Self
pub fn new(label: impl Into<SharedString>) -> Self
Create a new SidebarMenuItem with a label.
Sourcepub fn on_click(
self,
handler: impl Fn(&ClickEvent, &mut Window, &mut App) + 'static,
) -> Self
pub fn on_click( self, handler: impl Fn(&ClickEvent, &mut Window, &mut App) + 'static, ) -> Self
Add a click handler to the menu item
Sourcepub fn default_open(self, open: bool) -> Self
pub fn default_open(self, open: bool) -> Self
Set the default open state of the Submenu, default is false.
This only used on initial render, the internal state will be used afterwards.
Sourcepub fn click_to_open(self, click_to_open: bool) -> Self
pub fn click_to_open(self, click_to_open: bool) -> Self
Set whether clicking the menu item open the submenu.
Default is false.
If false we only handle open/close via the caret button.
Sourcepub fn click_to_toggle(self, click_to_toggle: bool) -> Self
pub fn click_to_toggle(self, click_to_toggle: bool) -> Self
Set whether clicking the menu item toggles the submenu.
If click_to_open is true, this has no effect.
Default is false.
pub fn children( self, children: impl IntoIterator<Item = impl Into<Self>>, ) -> Self
Set the context menu for the menu item.