Module text
rgpui_
component
0.3.0
Module text
Module Items
Structs
Enums
Functions
In crate rgpui_
component
rgpui_component
Module
text
Structs

Text
View
A text view that can render Markdown or HTML.
Text
View
Layout
State
Text
View
State
The state of a TextView.
Text
View
Style
TextViewStyle used to customize the style for [
TextView
].
Enums

Text
Functions

html
Create a new html text view with code location as id.
markdown
Create a new markdown text view with code location as id.
plain
创建一个新的纯文本文本视图,使用代码位置作为 id。