pub struct TreeState { /* private fields */ }Expand description
State for managing tree items.
Implementations
Sourceimpl TreeState
impl TreeState
Sourcepub fn set_items(
&mut self,
items: impl Into<Vec<TreeItem>>,
cx: &mut Context<'_, Self>,
)
pub fn set_items( &mut self, items: impl Into<Vec<TreeItem>>, cx: &mut Context<'_, Self>, )
Set the tree items.
Sourcepub fn selected_index(&self) -> Option<usize>
pub fn selected_index(&self) -> Option<usize>
Get the currently selected index, if any.
Sourcepub fn set_selected_index(
&mut self,
ix: Option<usize>,
cx: &mut Context<'_, Self>,
)
pub fn set_selected_index( &mut self, ix: Option<usize>, cx: &mut Context<'_, Self>, )
Set the selected index, or None to clear selection.
Sourcepub fn set_selected_item(
&mut self,
item: Option<&TreeItem>,
cx: &mut Context<'_, Self>,
)
pub fn set_selected_item( &mut self, item: Option<&TreeItem>, cx: &mut Context<'_, Self>, )
Set the selected index by tree item, or None to clear selection.
Sourcepub fn selected_item(&self) -> Option<&TreeItem>
pub fn selected_item(&self) -> Option<&TreeItem>
Get the currently selected tree item, if any.
pub fn scroll_to_item(&mut self, ix: usize, strategy: ScrollStrategy)
Sourcepub fn selected_entry(&self) -> Option<&TreeEntry>
pub fn selected_entry(&self) -> Option<&TreeEntry>
Get the currently selected entry, if any.
pub fn focus(&mut self, window: &mut Window, cx: &mut App)